@@ -32,8 +32,10 @@ from . import pprint
 
 
 class Emacs:
-    """
+    """!
     The Emacs class.
+
+    Used to create disposable Emacs processes.
     """
 
     def __init__(self, debug=False,
@@ -114,6 +116,19 @@ class Emacs:
 
         return self.eval(f"(princ {expression_string})", *args)
 
+    def eval_out(self, expression_string, *args):
+        """!
+        Evaluate an expression, print any output.
+
+        To ease calling for efect.
+
+        @param expression_string: expression string to evaluate
+        """
+
+        std_lines = self.execute("-q", *args, "--eval", expression_string)
+
+        pprint.std(std_lines)
+
     def get_version(self):
         """!
         Get the version of GNU Emacs.
@@ -130,15 +145,18 @@ class Emacs:
 
         return emacs_version
 
-    def eval_out(self, expression_string, *args):
+    def package_installed_p(self, package_name):
         """!
-        Evaluate an expression, print any output.
+        Check if a package is installed.
 
-        To ease calling for efect.
+        @param package_name: package name
 
-        @param expression_string: expression string to evaluate
+        @returns Boolean - True is installed, False if not
         """
 
-        std_lines = self.execute("-q", *args, "--eval", expression_string)
+        stdout_lines = self.eval_princ(
+            "(progn (require 'package) " +
+            "(package-initialize) " +
+            f"(package-installed-p '{package_name}))")
 
-        pprint.std(std_lines)
+        return "t" in stdout_lines
