@@ -54,7 +54,7 @@ def extract_summary(function):
 
 
 def make_parser():
-    """
+    """!
     Return argument parser for CLI arguments.
     """
 
@@ -142,6 +142,16 @@ def make_parser():
         nargs="*"
     )
 
+    sub_delete = subparser.add_parser(
+        "delete",
+        help=extract_summary(tasks.Tasks.package_delete)
+    )
+    sub_delete.add_argument(
+        "package",
+        help="Package to delete",
+        type=str,
+    )
+
     sub_eval = subparser.add_parser(
         "eval",
         help=extract_summary(tasks.Tasks.elisp_eval)
@@ -154,7 +164,7 @@ def make_parser():
 
     sub_install_local = subparser.add_parser(
         "install-local",
-        help=extract_summary(tasks.Tasks.install_local)
+        help=extract_summary(tasks.Tasks.package_install_local)
     )
     sub_install_local.add_argument(
         "path",
@@ -166,7 +176,7 @@ def make_parser():
 
     sub_install_remote = subparser.add_parser(
         "install-remote",
-        help=extract_summary(tasks.Tasks.install_remote)
+        help=extract_summary(tasks.Tasks.package_install_remote)
     )
     sub_install_remote.add_argument(
         "-a", "--add",
@@ -221,7 +231,7 @@ def make_parser():
 
 
 def main():
-    """
+    """!
     Main.
     """
 
@@ -258,14 +268,17 @@ def main():
     elif args.command == "compile-dir":
         emacs_tasks.elisp_compile_dir(args.directory)
 
+    elif args.command == "delete":
+        emacs_tasks.package_delete(args.package)
+
     elif args.command == "eval":
         emacs_tasks.elisp_eval(args.expression)
 
     elif args.command == "install-local":
-        emacs_tasks.install_local(args.path)
+        emacs_tasks.package_install_local(args.path)
 
     elif args.command == "install-remote":
-        emacs_tasks.install_remote(
+        emacs_tasks.package_install_remote(
             args.package,
             add_archive=args.add,
             use_archive=args.use,
