@@ -31,8 +31,10 @@ from .pprint import BLUE, BRIGHT, GREEN, MAGENTA, RESET
 
 
 def pinfo(emacs):
-    """
+    """!
     Print short info about the program.
+
+    @param emacs: a Emacs object
     """
 
     python_version = f"{version_info.major}.{version_info.minor}"
