@@ -42,32 +42,40 @@ RESET = colorama.Fore.RESET + colorama.Style.RESET_ALL
 
 
 def debug(string):
-    """
+    """!
     Debug print.
+
+    @param: string to print
     """
 
     print(f"  {BRIGHT}{WHITE}[{YELLOW}***{WHITE}]{RESET}: {string}")
 
 
 def info(string):
-    """
+    """!
     Debug print.
+
+    @param: string to print
     """
 
     print(f"  {BRIGHT}{WHITE}[{GREEN}...{WHITE}]{RESET}: {string}")
 
 
 def warning(string):
-    """
+    """!
     Debug print.
+
+    @param: string to print
     """
 
     print(f"  {BRIGHT}{WHITE}[{RED}!!!{WHITE}]{RESET}: {string}")
 
 
 def std(std_lines):
-    """
+    """!
     Helper to print "stdout" and "stderr" from std_lines.
+
+    @param: dict of lines to print
     """
 
     for stdout_line in std_lines["stdout"]:
@@ -82,6 +90,8 @@ def std(std_lines):
 def args(namespace):
     """!
     Pretty-print args from a given namespace.
+
+    @param: args namespace to print
     """
 
     for option, value in vars(namespace).items():
