@@ -33,7 +33,7 @@ from .task_generators import package_archives_generator, loader_generator
 
 
 class Tasks:
-    """
+    """!
     Class containing tasks to run.
     """
 
@@ -126,7 +126,30 @@ class Tasks:
             if self.verbose:
                 pprint.std(out_lines)
 
-    def install_local(self, package_paths):
+    def package_delete(self, package_name):
+        """!
+        Delete (uninstall) a installed package.
+
+        @param package_name: name of package to delete
+        """
+
+        if self.emacs.package_installed_p(package_name):
+            if self.verbose:
+                pprint.info(f"Deleting {package_name}...")
+
+            self.emacs.eval_out(
+                "(progn (require 'package) " +
+                "(package-initialize) " +
+                "(package-delete " +
+                f"(car (alist-get '{package_name} package-alist)) t))")
+
+            if self.verbose:
+                pprint.info(f"...done deleting {package_name}.")
+
+        elif self.verbose:
+            pprint.info(f"Package {package_name} is already not installed.")
+
+    def package_install_local(self, package_paths):
         """!
         Install specified package directories/files.
 
@@ -147,8 +170,8 @@ class Tasks:
             if self.verbose:
                 pprint.info(f"...done installing {package_path}.")
 
-    def install_remote(self, package_name,
-                       add_archive=False, use_archive=False, refresh=True):
+    def package_install_remote(self, package_name, add_archive=False,
+                               use_archive=False, refresh=True):
         """!
         Install a remote package.
 
